__quantum__qis__exp__adj

Function __quantum__qis__exp__adj 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn __quantum__qis__exp__adj( paulis: *const QirArray, theta: c_double, qubits: *const QirArray, )
QIR API for applying an adjoint exponential of a multi-qubit rotation about the given Pauli axes with the given angle and qubits.

Safety

This function should only be called with arrays and tuples created by the QIR runtime library.