__quantum__qis__exp__body

Function __quantum__qis__exp__body 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn __quantum__qis__exp__body( paulis: *const QirArray, theta: c_double, qubits: *const QirArray, )
QIR API for applying an exponential of a multi-qubit rotation about the given Pauli axes with the given angle and qubits.

Safety

This function should only be called with arrays and tuples created by the QIR runtime library.